#!/bin/sh
. /root/gstreamer-examples/func.sh

init_dev ISP
[ $? -ne 0 ] && exit 1

CROP_CTRL=""
echo " select resolution"
echo " ================="
echo " 1 = 1920 x 1200 Full"
echo " 2 = 1920 x 1080 HD, with Crop the Full Frame in the ISP"
echo " 3 = 1920 x 1080 HD, with Crop the Full Frame in the Sensor"
echo " 4 = 1280 x 720 HD, with Crop the Full Frame in the ISP"
echo " 5 = 1280 x 720 HD, with Crop the Full Frame in the Sensor"
read RESOLUTION
echo " Your select = $RESOLUTION"
case $RESOLUTION in
  "1") SENSOR_RES="1920x1200"; FRAME_SIZE_FROM_ISP="width=1920,height=1200"; MODE_VAR=$VM_020_AO082_1920x1200;;
  "2") SENSOR_RES="1920x1200"; FRAME_SIZE_FROM_ISP="width=1920,height=1080"; MODE_VAR=$VM_020_AO082_1920x1200; CROP_CTRL="--set-crop=top=60,left=0,width=1920,height=1080";;
  "3") SENSOR_RES="1920x1080"; FRAME_SIZE_FROM_ISP="width=1920,height=1080"; MODE_VAR=$VM_020_AO082_1920x1080;;
  "4") SENSOR_RES="1920x1200"; FRAME_SIZE_FROM_ISP="width=1280,height=720"; MODE_VAR=$VM_020_AO082_1920x1200; CROP_CTRL="--set-crop=top=240,left=320,width=1280,height=720";;
  "5") SENSOR_RES="1280x720"; FRAME_SIZE_FROM_ISP="width=1280,height=720"; MODE_VAR=$VM_020_AO082_1280x720;;
  *) SENSOR_RES="1920x1200"; FRAME_SIZE_FROM_ISP="width=1920,height=1200"; MODE_VAR=$VM_020_AO082_1920x1200;;
esac

echo " ================================================================================="
echo " starting gstreamer with COLOR (YUV) Source after ISP ..."
echo " read from sensor $SENSOR_RES, read after ISP $FRAME_SIZE_FROM_ISP, convert and write to framebuffer"
echo " ================================================================================="
echo ""
echo " choose right XML-File and JSON-File in Sensor0_Entry.cfg"
echo " ========================================================"

sed -i 's/^mode= .*/mode= '$MODE_VAR'/' $(readlink -f /opt/imx8-isp/bin/Sensor0_Entry.cfg)
XML_FILE=`grep -A1 mode.$MODE_VAR /opt/imx8-isp/bin/Sensor0_Entry.cfg | grep xml | cut -c12- | sed 's/"//g'`
JSON_FILE=`grep -A2 mode.$MODE_VAR /opt/imx8-isp/bin/Sensor0_Entry.cfg | grep json | cut -c12- | sed 's/"//g'`
echo " XML_File for ISP  = $XML_FILE"
echo " JSON_File for ISP = $JSON_FILE"


echo ""
echo " configure CSI1 (CAM1 port) with media_control"
echo " ============================================="

if [ -e /dev/phycam-deserializer-csi1 ] && [ -e /dev/phycam-serializer-csi1 ] ; then
	DESERIALIZER="$(cat /sys/class/video4linux/$(readlink /dev/phycam-deserializer-csi1)/name)"
	SERIALIZER="$(cat /sys/class/video4linux/$(readlink /dev/phycam-serializer-csi1)/name)"
	media-ctl -l "'${SERIALIZER}':1->'${DESERIALIZER}':0[1]"
fi


echo ""
echo " configure camera @CAM1 with v4l2_control"
echo " ========================================"

if [ "$(v4l2-ctl -d ${CAM_DEVICE} --get-subdev-fmt 0 | grep "Mediabus Code" | sed 's/.*BUS_FMT_\([A-Z]*\).*/\1/g')" = "Y" ]; then
	$V4L2_CTRL_CAM1_BW_ISP
else
	$V4L2_CTRL_CAM1_COL_ISP
fi

if [ -n "$CROP_CTRL" ] ; then
	v4l2-ctl -d ${VID_DEVICE} ${CROP_CTRL}
fi

echo ""
echo " start gstreamer, break with ctl-C"
echo " ================================="

gst-launch-1.0 \
	v4l2src device=$VID_DEVICE ! \
	video/x-raw,format=YUY2,$FRAME_SIZE_FROM_ISP ! \
	waylandsink sync=false
